==> portal-service-5.2.3-sources.jar: com/liferay/portal/util/PortletKeys.java <==
/**
 * Copyright (c) 2000-2009 Liferay, Inc. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.liferay.portal.util;

/**
 * <a href="PortletKeys.java.html"><b><i>View Source</i></b></a>
 *
 * @author Brian Wing Shun Chan
 *
 */
public class PortletKeys {

	public static final String ACTIVITIES = "116";

	public static final String ADMIN = "9";

	public static final String ADMIN_INSTANCE = "135";

	public static final String ADMIN_PLUGINS = "136";

	public static final String ADMIN_SERVER = "137";

	public static final String ALERTS = "83";

	public static final String ANNOUNCEMENTS = "84";

	public static final String ASSET_PUBLISHER = "101";

	public static final String BOOKMARKS = "28";

	public static final String BLOGS = "33";

	public static final String BLOGS_AGGREGATOR = "115";

	public static final String CALENDAR = "8";

	public static final String CHAT = "1_WAR_chatportlet";

	public static final String COMMUNITIES = "29";

	public static final String DOCUMENT_LIBRARY = "20";

	public static final String DIRECTORY = "11";

	public static final String ENTERPRISE_ADMIN = "79";

	public static final String ENTERPRISE_ADMIN_COMMUNITIES = "134";

	public static final String ENTERPRISE_ADMIN_MONITORING = "131";

	public static final String ENTERPRISE_ADMIN_PASSWORD_POLICIES = "129";

	public static final String ENTERPRISE_ADMIN_PLUGINS = "132";

	public static final String ENTERPRISE_ADMIN_ROLES = "128";

	public static final String ENTERPRISE_ADMIN_SETTINGS = "130";

	public static final String ENTERPRISE_ADMIN_ORGANIZATIONS = "126";

	public static final String ENTERPRISE_ADMIN_USER_GROUPS = "127";

	public static final String ENTERPRISE_ADMIN_USERS = "125";

	public static final String EXPANDO = "139";

	public static final String FLAGS = "142";

	public static final String IFRAME = "48";

	public static final String IMAGE_GALLERY = "31";

	public static final String INVITATION = "100";

	public static final String JOURNAL = "15";

	public static final String JOURNAL_CONTENT = "56";

	public static final String JOURNAL_CONTENT_SEARCH = "77";

	public static final String LANGUAGE = "82";

	public static final String LAYOUT_CONFIGURATION = "87";

	public static final String LAYOUT_MANAGEMENT = "88";

	public static final String LIFERAY_PORTAL = "LIFERAY_PORTAL";

	public static final String LOGIN = "58";

	public static final String MAIL = "1";

	public static final String MESSAGE_BOARDS = "19";

	public static final String MY_ACCOUNT = "2";

	public static final String MY_PAGES = "140";

	public static final String MY_PLACES = "49";

	public static final String NESTED_PORTLETS = "118";

	public static final String ORGANIZATION_ADMIN = "80";

	public static final String PAGE_COMMENTS = "107";

	public static final String PAGE_RATINGS = "108";

	public static final String PLUGIN_INSTALLER = "111";

	public static final String POLLS = "25";

	public static final String PORTAL = "90";

	public static final String PORTLET_CONFIGURATION = "86";

	public static final String PORTLET_CSS = "113";

	public static final long PREFS_OWNER_ID_DEFAULT = 0;

	public static final int PREFS_OWNER_TYPE_COMPANY = 1;

	public static final int PREFS_OWNER_TYPE_GROUP = 2;

	public static final int PREFS_OWNER_TYPE_LAYOUT = 3;

	public static final int PREFS_OWNER_TYPE_USER = 4;

	public static final int PREFS_OWNER_TYPE_ARCHIVED = 5;

	public static final int PREFS_OWNER_TYPE_ORGANIZATION  = 6;

	public static final long PREFS_PLID_SHARED = 0;

	public static final String RECENT_BLOGGERS = "114";

	public static final String RECENT_DOCUMENTS = "64";

	public static final String REQUESTS = "121";

	public static final String SEARCH = "3";

	public static final String SHOPPING = "34";

	public static final String SOFTWARE_CATALOG = "98";

	public static final String STOCKS = "12";

	public static final String TAGS_ADMIN = "99";

	public static final String TAGS_CATEGORIES_NAVIGATION = "122";

	public static final String TAGS_COMPILER = "103";

	public static final String TAGS_ENTRIES_NAVIGATION = "141";

	public static final String TASKS = "122";

	public static final String UPDATE_MANAGER = "104";

	public static final String WIKI = "36";

	public static final String WORKFLOW = "93";

}

==> portal-service-6.0.2-sources.jar: com/liferay/portal/util/PortletKeys.java <==
/**
 * Copyright (c) 2000-2010 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portal.util;

/**
 * <a href="PortletKeys.java.html"><b><i>View Source</i></b></a>
 *
 * @author Brian Wing Shun Chan
 */
public class PortletKeys {

	public static final String ACTIVITIES = "116";

	public static final String ADMIN = "9";

	public static final String ADMIN_INSTANCE = "135";

	public static final String ADMIN_PLUGINS = "136";

	public static final String ADMIN_SERVER = "137";

	public static final String ALERTS = "83";

	public static final String ANNOUNCEMENTS = "84";

	public static final String ASSET_PUBLISHER = "101";

	public static final String BLOGS = "33";

	public static final String BLOGS_AGGREGATOR = "115";

	public static final String BOOKMARKS = "28";

	public static final String CALENDAR = "8";

	public static final String CHAT = "1_WAR_chatportlet";

	public static final String COMMUNITIES = "29";

	public static final String CURRENCY_CONVERTER = "16";

	public static final String DICTIONARY = "23";

	public static final String DIRECTORY = "11";

	public static final String DOCKBAR = "145";

	public static final String DOCUMENT_LIBRARY = "20";

	public static final String DOCUMENT_LIBRARY_DISPLAY = "110";

	public static final String ENTERPRISE_ADMIN = "79";

	public static final String ENTERPRISE_ADMIN_COMMUNITIES = "134";

	public static final String ENTERPRISE_ADMIN_MONITORING = "131";

	public static final String ENTERPRISE_ADMIN_ORGANIZATIONS = "126";

	public static final String ENTERPRISE_ADMIN_PASSWORD_POLICIES = "129";

	public static final String ENTERPRISE_ADMIN_PLUGINS = "132";

	public static final String ENTERPRISE_ADMIN_ROLES = "128";

	public static final String ENTERPRISE_ADMIN_SETTINGS = "130";

	public static final String ENTERPRISE_ADMIN_USER_GROUPS = "127";

	public static final String ENTERPRISE_ADMIN_USERS = "125";

	public static final String EXPANDO = "139";

	public static final String FLAGS = "142";

	public static final String IFRAME = "48";

	public static final String IMAGE_GALLERY = "31";

	public static final String INVITATION = "100";

	public static final String JOURNAL = "15";

	public static final String JOURNAL_CONTENT = "56";

	public static final String JOURNAL_CONTENT_SEARCH = "77";

	public static final String KNOWLEDGE_BASE_ADMIN =
		"1_WAR_knowledgebaseportlet";

	public static final String LANGUAGE = "82";

	public static final String LAYOUT_CONFIGURATION = "87";

	public static final String LAYOUT_MANAGEMENT = "88";

	public static final String LIFERAY_PORTAL = "LIFERAY_PORTAL";

	public static final String LOGIN = "58";

	public static final String MAIL = "1_WAR_mailportlet";

	public static final String MESSAGE_BOARDS = "19";

	public static final String MY_ACCOUNT = "2";

	public static final String MY_PAGES = "140";

	public static final String MY_PLACES = "49";

	public static final String NESTED_PORTLETS = "118";

	public static final String ORGANIZATION_ADMIN = "80";

	public static final String PAGE_COMMENTS = "107";

	public static final String PAGE_RATINGS = "108";

	public static final String PLUGIN_INSTALLER = "111";

	public static final String POLLS = "25";

	public static final String POLLS_DISPLAY = "59";

	public static final String PORTAL = "90";

	public static final String PORTLET_CONFIGURATION = "86";

	public static final String PORTLET_CSS = "113";

	public static final long PREFS_OWNER_ID_DEFAULT = 0;

	public static final int PREFS_OWNER_TYPE_ARCHIVED = 5;

	public static final int PREFS_OWNER_TYPE_COMPANY = 1;

	public static final int PREFS_OWNER_TYPE_GROUP = 2;

	public static final int PREFS_OWNER_TYPE_LAYOUT = 3;

	public static final int PREFS_OWNER_TYPE_ORGANIZATION  = 6;

	public static final int PREFS_OWNER_TYPE_USER = 4;

	public static final long PREFS_PLID_SHARED = 0;

	public static final String RECENT_BLOGGERS = "114";

	public static final String RECENT_DOCUMENTS = "64";

	public static final String REQUESTS = "121";

	public static final String RSS = "39";

	public static final String SEARCH = "3";

	public static final String SHOPPING = "34";

	public static final String SMS_TEXT_MESSENGER = "24";

	public static final String SOFTWARE_CATALOG = "98";

	public static final String STOCKS = "12";

	public static final String TAGS_ADMIN = "99";

	public static final String TAGS_CATEGORIES_NAVIGATION = "122";

	public static final String TAGS_CLOUD = "148";

	public static final String TAGS_COMPILER = "103";

	public static final String TAGS_ENTRIES_NAVIGATION = "141";

	public static final String TRANSLATOR = "26";

	public static final String UNIT_CONVERTER = "27";

	public static final String UPDATE_MANAGER = "104";

	public static final String WIKI = "36";

	public static final String WIKI_ADMIN = "154";

	public static final String WORKFLOW_TASKS = "150";

	public static final String WORKFLOW_DEFINITIONS = "151";

	public static final String WORKFLOW_CONFIGURATION = "152";

	public static final String MY_WORKFLOW_TASKS = "153";

}
